@@ -19,7 +19,7 @@ use Safe::Isa;
 
 use Moo;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use constant GridObject   => InstanceOf [ ( __PACKAGE__ ) ];
 use constant IncludeArray => ArrayRef [ Enum [ 0, 1 ] ];
@@ -885,8 +885,8 @@ sub _overload_not ( $self, $, $ ) {
 
 
 
-sub _overload_or ( $self, $other, $ ) {
-
+# need extra args if bitwise feature is on.
+sub _overload_or ( $self, $other, $ =, $ =, $ = ) {
     $other->$_isa( __PACKAGE__ )
       or die( "can only perform the | operation between two ${ \__PACKAGE__ } objects " );
     return $self->or( $other );
@@ -1076,7 +1076,7 @@ CXC::Number::Grid - A class representing a one dimensional numeric grid
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
